IsEvenAiFirebaseVertexAi class final
✨Firebase VertexAI✨ implementation to check if a number is even.
Constructors
- IsEvenAiFirebaseVertexAi({required GenerativeModel model})
-
Create instance of Firebase VertexAI implementation.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
areEqual(
num a, num b) → Future< bool> -
Returns if the two numbers are equal.
override
-
areNotEqual(
num a, num b) → Future< bool> -
Returns if the two numbers are NOT equal.
override
-
isEven(
num value) → Future< bool> -
Returns if the number is even.
override
-
isGreaterThan(
num a, num b) → Future< bool> -
Returns if first number
ais greater than second numberb.override -
isLessThan(
num a, num b) → Future< bool> -
Returns if first number
ais less than second numberb.override -
isOdd(
num value) → Future< bool> -
Returns if the number is odd.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited